@@ -68,10 +68,8 @@ def get_dims(ess):
 import uvicorn,fastapi
 app	= fastapi.FastAPI() 
 
-@app.post('/dims/snts')
-def snts_to_dims(snts:list=["She has ready.","I believe I can do it."], local_parse:bool=True):
+def docs_to_dims(snts:list, docs:list):
 	''' updated 2022.3.20 '''
-	docs = [spacy.nlp(snt) if local_parse else spacy.getdoc(snt) for snt in snts]
 	ess = {'snts': snts, 'docs': docs, 'tc': sum([len(d) for d in docs]), 'snt_num': len(docs), 
 		'pred_verbs':{ t.lemma_ for d in docs for t in d if t.dep_ == 'ROOT' and t.tag_.startswith('V') and t.lemma_ in word_idf},
 		'word_num': sum([len(d) for d in docs]), 
@@ -81,6 +79,13 @@ def snts_to_dims(snts:list=["She has ready.","I believe I can do it."], local_pa
 	dims.update({"tc": ess['tc'], "snt_num": ess['snt_num'], "word_num": ess['word_num'], "word_type": ess['word_type']})
 	return dims
 
+
+@app.post('/dims/snts')
+def snts_to_dims(snts:list=["She has ready.","I believe I can do it."], use_cache:bool=True):
+	''' updated 2022.3.20 '''
+	docs = [spacy.getdoc(snt, use_cache) for snt in snts]
+	return docs_to_dims(snts, docs) 
+
 @app.get('/dims/essay')
 def essay_to_dims(essay:str="She has ready. I believe I can do it."): 	
 	''' updated 2022.3.20 '''
