@@ -160,10 +160,27 @@ class ES(object):
 		print(">>finished " + idxname )
 
 	def clear(self,idxname): self.es.delete_by_query(index=idxname, body={"query": {"match_all": {}}})
-	def dump(self, idxname): [print (doc['_id'] + "\t" + json.dumps(doc['_source']))  for doc in helpers.scan(self.es,query={"query": {"match_all": {}}}, index=idxname)]
+	def dumpid(self, idxname): [print (doc['_id'] + "\t" + json.dumps(doc['_source']))  for doc in helpers.scan(self.es,query={"query": {"match_all": {}}}, index=idxname)]
+	def dump(self, idxname): [print (json.dumps(doc))  for doc in helpers.scan(self.es,query={"query": {"match_all": {}}}, index=idxname)]
 	def keys(self, idxname): [print(resp['_id']) for resp in  helpers.scan(client=self.es, query={"query" : {"match_all" : {}}}, scroll= "10m", index= idxname , timeout="10m") ]
 	def hello(self): print (self.es)
 
+	def load(self, infile, idxname, batch=100000): 
+		''' load id-source-file into index, 2022.3.29 '''
+		actions=[]
+		for line in readline(infile): 
+			try:
+				arr = json.loads(line) 
+				arr.update({'_op_type':'index', '_index':idxname,}) 
+				if len(actions) > batch: 
+					helpers.bulk(client=self.es,actions=actions, raise_on_error=False)
+					print ( actions[-1], flush=True)
+					actions = []
+			except Exception as e:
+				print("ex:", e)	
+		if actions : helpers.bulk(client=self.es,actions=actions, raise_on_error=False)
+		return actions 
+
 if __name__ == '__main__':
 	fire.Fire(ES)
 
